# coding: utf-8

"""
    Imports

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.crm.imports.configuration import Configuration


class PublicImportError(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "created_at": "int",
        "extra_context": "str",
        "object_type_id": "str",
        "error_type": "str",
        "invalid_property_value": "PropertyValue",
        "error_message": "str",
        "known_column_number": "int",
        "invalid_value_to_display": "str",
        "id": "str",
        "source_data": "ImportRowCore",
        "object_type": "str",
        "invalid_value": "str",
    }

    attribute_map = {
        "created_at": "createdAt",
        "extra_context": "extraContext",
        "object_type_id": "objectTypeId",
        "error_type": "errorType",
        "invalid_property_value": "invalidPropertyValue",
        "error_message": "errorMessage",
        "known_column_number": "knownColumnNumber",
        "invalid_value_to_display": "invalidValueToDisplay",
        "id": "id",
        "source_data": "sourceData",
        "object_type": "objectType",
        "invalid_value": "invalidValue",
    }

    def __init__(
        self,
        created_at=None,
        extra_context=None,
        object_type_id=None,
        error_type=None,
        invalid_property_value=None,
        error_message=None,
        known_column_number=None,
        invalid_value_to_display=None,
        id=None,
        source_data=None,
        object_type=None,
        invalid_value=None,
        local_vars_configuration=None,
    ):  # noqa: E501
        """PublicImportError - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._created_at = None
        self._extra_context = None
        self._object_type_id = None
        self._error_type = None
        self._invalid_property_value = None
        self._error_message = None
        self._known_column_number = None
        self._invalid_value_to_display = None
        self._id = None
        self._source_data = None
        self._object_type = None
        self._invalid_value = None
        self.discriminator = None

        self.created_at = created_at
        if extra_context is not None:
            self.extra_context = extra_context
        if object_type_id is not None:
            self.object_type_id = object_type_id
        self.error_type = error_type
        if invalid_property_value is not None:
            self.invalid_property_value = invalid_property_value
        if error_message is not None:
            self.error_message = error_message
        if known_column_number is not None:
            self.known_column_number = known_column_number
        if invalid_value_to_display is not None:
            self.invalid_value_to_display = invalid_value_to_display
        self.id = id
        self.source_data = source_data
        if object_type is not None:
            self.object_type = object_type
        if invalid_value is not None:
            self.invalid_value = invalid_value

    @property
    def created_at(self):
        """Gets the created_at of this PublicImportError.  # noqa: E501


        :return: The created_at of this PublicImportError.  # noqa: E501
        :rtype: int
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this PublicImportError.


        :param created_at: The created_at of this PublicImportError.  # noqa: E501
        :type created_at: int
        """
        if self.local_vars_configuration.client_side_validation and created_at is None:  # noqa: E501
            raise ValueError("Invalid value for `created_at`, must not be `None`")  # noqa: E501

        self._created_at = created_at

    @property
    def extra_context(self):
        """Gets the extra_context of this PublicImportError.  # noqa: E501


        :return: The extra_context of this PublicImportError.  # noqa: E501
        :rtype: str
        """
        return self._extra_context

    @extra_context.setter
    def extra_context(self, extra_context):
        """Sets the extra_context of this PublicImportError.


        :param extra_context: The extra_context of this PublicImportError.  # noqa: E501
        :type extra_context: str
        """

        self._extra_context = extra_context

    @property
    def object_type_id(self):
        """Gets the object_type_id of this PublicImportError.  # noqa: E501


        :return: The object_type_id of this PublicImportError.  # noqa: E501
        :rtype: str
        """
        return self._object_type_id

    @object_type_id.setter
    def object_type_id(self, object_type_id):
        """Sets the object_type_id of this PublicImportError.


        :param object_type_id: The object_type_id of this PublicImportError.  # noqa: E501
        :type object_type_id: str
        """

        self._object_type_id = object_type_id

    @property
    def error_type(self):
        """Gets the error_type of this PublicImportError.  # noqa: E501


        :return: The error_type of this PublicImportError.  # noqa: E501
        :rtype: str
        """
        return self._error_type

    @error_type.setter
    def error_type(self, error_type):
        """Sets the error_type of this PublicImportError.


        :param error_type: The error_type of this PublicImportError.  # noqa: E501
        :type error_type: str
        """
        if self.local_vars_configuration.client_side_validation and error_type is None:  # noqa: E501
            raise ValueError("Invalid value for `error_type`, must not be `None`")  # noqa: E501
        allowed_values = [
            "INCORRECT_NUMBER_OF_COLUMNS",
            "INVALID_OBJECT_ID",
            "INVALID_ASSOCIATION_IDENTIFIER",
            "NO_OBJECT_ID_FROM_ASSOCIATION_IDENTIFIER",
            "MULTIPLE_COMPANIES_WITH_THIS_DOMAIN",
            "PROPERTY_DEFINITION_NOT_FOUND",
            "PROPERTY_VALUE_NOT_FOUND",
            "COULD_NOT_FIND_OWNER",
            "MULTIPLE_OWNERS_FOUND",
            "COULD_NOT_FIND_BUSINESS_UNIT",
            "COULD_NOT_PARSE_NUMBER",
            "COULD_NOT_PARSE_DATE",
            "COULD_NOT_PARSE_TERM",
            "OUTSIDE_VALID_TIME_RANGE",
            "OUTSIDE_VALID_TERM_RANGE",
            "COULD_NOT_PARSE_ROW",
            "INVALID_ENUMERATION_OPTION",
            "AMBIGUOUS_ENUMERATION_OPTION",
            "FAILED_VALIDATION",
            "FAILED_TO_CREATE_ASSOCIATION",
            "ASSOCIATION_LIMIT_EXCEEDED",
            "FILE_NOT_FOUND",
            "INVALID_COLUMN_CONFIGURATION",
            "INVALID_FILE_TYPE",
            "INVALID_SPREADSHEET",
            "INVALID_SHEET_COUNT",
            "FAILED_TO_PROCESS_OBJECT_WITH_EMPTY_PROPERTY_VALUES",
            "UNKNOWN_BAD_REQUEST",
            "GDPR_BLACKLISTED_EMAIL",
            "DUPLICATE_ASSOCIATION_ID",
            "LIMIT_EXCEEDED",
            "PORTAL_WIDE_CUSTOM_OBJECT_LIMIT_EXCEEDED",
            "INVALID_ALTERNATE_ID",
            "INVALID_EMAIL",
            "SECONDARY_EMAIL_WRITE_FAILURE",
            "INVALID_DOMAIN",
            "DUPLICATE_ROW_CONTENT",
            "INVALID_NUMBER_SIZE",
            "UNKNOWN_ERROR",
            "FAILED_TO_OPT_OUT_CONTACT",
            "INVALID_REQUIRED_PROPERTY",
            "MISSING_REQUIRED_PROPERTY",
            "DUPLICATE_ALTERNATE_ID",
            "DUPLICATE_OBJECT_ID",
            "DUPLICATE_UNIQUE_PROPERTY_VALUE",
            "UNKNOWN_ASSOCIATION_RECORD_ID",
            "INVALID_RECORD_ID",
            "DUPLICATE_RECORD_ID",
            "INVALID_CUSTOM_PROPERTY_VALIDATION",
            "CREATE_ONLY_IMPORT",
            "UPDATE_ONLY_IMPORT",
            "COLUMN_TOO_LARGE",
            "ROW_DATA_TOO_LARGE",
            "MISSING_EVENT_TIMESTAMP",
            "INVALID_EVENT_TIMESTAMP",
            "INVALID_EVENT",
            "DUPLICATE_EVENT",
            "MISSING_EVENT_DEFINITION",
            "INVALID_ASSOCIATION_KEY",
            "ASSOCIATION_RECORD_NOT_FOUND",
            "MISSING_OBJECT_DEFINITION",
            "ASSOCIATION_LABEL_NOT_FOUND",
            "MANY_ERRORS_IN_ROW",
        ]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and error_type not in allowed_values:  # noqa: E501
            raise ValueError("Invalid value for `error_type` ({0}), must be one of {1}".format(error_type, allowed_values))  # noqa: E501

        self._error_type = error_type

    @property
    def invalid_property_value(self):
        """Gets the invalid_property_value of this PublicImportError.  # noqa: E501


        :return: The invalid_property_value of this PublicImportError.  # noqa: E501
        :rtype: PropertyValue
        """
        return self._invalid_property_value

    @invalid_property_value.setter
    def invalid_property_value(self, invalid_property_value):
        """Sets the invalid_property_value of this PublicImportError.


        :param invalid_property_value: The invalid_property_value of this PublicImportError.  # noqa: E501
        :type invalid_property_value: PropertyValue
        """

        self._invalid_property_value = invalid_property_value

    @property
    def error_message(self):
        """Gets the error_message of this PublicImportError.  # noqa: E501


        :return: The error_message of this PublicImportError.  # noqa: E501
        :rtype: str
        """
        return self._error_message

    @error_message.setter
    def error_message(self, error_message):
        """Sets the error_message of this PublicImportError.


        :param error_message: The error_message of this PublicImportError.  # noqa: E501
        :type error_message: str
        """

        self._error_message = error_message

    @property
    def known_column_number(self):
        """Gets the known_column_number of this PublicImportError.  # noqa: E501


        :return: The known_column_number of this PublicImportError.  # noqa: E501
        :rtype: int
        """
        return self._known_column_number

    @known_column_number.setter
    def known_column_number(self, known_column_number):
        """Sets the known_column_number of this PublicImportError.


        :param known_column_number: The known_column_number of this PublicImportError.  # noqa: E501
        :type known_column_number: int
        """

        self._known_column_number = known_column_number

    @property
    def invalid_value_to_display(self):
        """Gets the invalid_value_to_display of this PublicImportError.  # noqa: E501


        :return: The invalid_value_to_display of this PublicImportError.  # noqa: E501
        :rtype: str
        """
        return self._invalid_value_to_display

    @invalid_value_to_display.setter
    def invalid_value_to_display(self, invalid_value_to_display):
        """Sets the invalid_value_to_display of this PublicImportError.


        :param invalid_value_to_display: The invalid_value_to_display of this PublicImportError.  # noqa: E501
        :type invalid_value_to_display: str
        """

        self._invalid_value_to_display = invalid_value_to_display

    @property
    def id(self):
        """Gets the id of this PublicImportError.  # noqa: E501


        :return: The id of this PublicImportError.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this PublicImportError.


        :param id: The id of this PublicImportError.  # noqa: E501
        :type id: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def source_data(self):
        """Gets the source_data of this PublicImportError.  # noqa: E501


        :return: The source_data of this PublicImportError.  # noqa: E501
        :rtype: ImportRowCore
        """
        return self._source_data

    @source_data.setter
    def source_data(self, source_data):
        """Sets the source_data of this PublicImportError.


        :param source_data: The source_data of this PublicImportError.  # noqa: E501
        :type source_data: ImportRowCore
        """
        if self.local_vars_configuration.client_side_validation and source_data is None:  # noqa: E501
            raise ValueError("Invalid value for `source_data`, must not be `None`")  # noqa: E501

        self._source_data = source_data

    @property
    def object_type(self):
        """Gets the object_type of this PublicImportError.  # noqa: E501


        :return: The object_type of this PublicImportError.  # noqa: E501
        :rtype: str
        """
        return self._object_type

    @object_type.setter
    def object_type(self, object_type):
        """Sets the object_type of this PublicImportError.


        :param object_type: The object_type of this PublicImportError.  # noqa: E501
        :type object_type: str
        """
        allowed_values = [
            "CONTACT",
            "COMPANY",
            "DEAL",
            "ENGAGEMENT",
            "TICKET",
            "OWNER",
            "PRODUCT",
            "LINE_ITEM",
            "BET_DELIVERABLE_SERVICE",
            "CONTENT",
            "CONVERSATION",
            "BET_ALERT",
            "PORTAL",
            "QUOTE",
            "FORM_SUBMISSION_INBOUNDDB",
            "QUOTA",
            "UNSUBSCRIBE",
            "COMMUNICATION",
            "FEEDBACK_SUBMISSION",
            "ATTRIBUTION",
            "SALESFORCE_SYNC_ERROR",
            "RESTORABLE_CRM_OBJECT",
            "HUB",
            "LANDING_PAGE",
            "PRODUCT_OR_FOLDER",
            "TASK",
            "FORM",
            "MARKETING_EMAIL",
            "AD_ACCOUNT",
            "AD_CAMPAIGN",
            "AD_GROUP",
            "AD",
            "KEYWORD",
            "CAMPAIGN",
            "SOCIAL_CHANNEL",
            "SOCIAL_POST",
            "SITE_PAGE",
            "BLOG_POST",
            "IMPORT",
            "EXPORT",
            "CTA",
            "TASK_TEMPLATE",
            "AUTOMATION_PLATFORM_FLOW",
            "OBJECT_LIST",
            "NOTE",
            "MEETING_EVENT",
            "CALL",
            "EMAIL",
            "PUBLISHING_TASK",
            "CONVERSATION_SESSION",
            "CONTACT_CREATE_ATTRIBUTION",
            "INVOICE",
            "MARKETING_EVENT",
            "CONVERSATION_INBOX",
            "CHATFLOW",
            "MEDIA_BRIDGE",
            "SEQUENCE",
            "SEQUENCE_STEP",
            "FORECAST",
            "SNIPPET",
            "TEMPLATE",
            "DEAL_CREATE_ATTRIBUTION",
            "QUOTE_TEMPLATE",
            "QUOTE_MODULE",
            "QUOTE_MODULE_FIELD",
            "QUOTE_FIELD",
            "SEQUENCE_ENROLLMENT",
            "SUBSCRIPTION",
            "ACCEPTANCE_TEST",
            "SOCIAL_BROADCAST",
            "DEAL_SPLIT",
            "DEAL_REGISTRATION",
            "GOAL_TARGET",
            "GOAL_TARGET_GROUP",
            "PORTAL_OBJECT_SYNC_MESSAGE",
            "FILE_MANAGER_FILE",
            "FILE_MANAGER_FOLDER",
            "SEQUENCE_STEP_ENROLLMENT",
            "APPROVAL",
            "APPROVAL_STEP",
            "CTA_VARIANT",
            "SALES_DOCUMENT",
            "DISCOUNT",
            "FEE",
            "TAX",
            "MARKETING_CALENDAR",
            "PERMISSIONS_TESTING",
            "PRIVACY_SCANNER_COOKIE",
            "DATA_SYNC_STATE",
            "WEB_INTERACTIVE",
            "PLAYBOOK",
            "FOLDER",
            "PLAYBOOK_QUESTION",
            "PLAYBOOK_SUBMISSION",
            "PLAYBOOK_SUBMISSION_ANSWER",
            "COMMERCE_PAYMENT",
            "GSC_PROPERTY",
            "SOX_PROTECTED_DUMMY_TYPE",
            "BLOG_LISTING_PAGE",
            "QUARANTINED_SUBMISSION",
            "PAYMENT_SCHEDULE",
            "PAYMENT_SCHEDULE_INSTALLMENT",
            "MARKETING_CAMPAIGN_UTM",
            "DISCOUNT_TEMPLATE",
            "DISCOUNT_CODE",
            "FEEDBACK_SURVEY",
            "CMS_URL",
            "SALES_TASK",
            "SALES_WORKLOAD",
            "USER",
            "POSTAL_MAIL",
            "SCHEMAS_BACKEND_TEST",
            "PAYMENT_LINK",
            "SUBMISSION_TAG",
            "CAMPAIGN_STEP",
            "SCHEDULING_PAGE",
            "SOX_PROTECTED_TEST_TYPE",
            "ORDER",
            "MARKETING_SMS",
            "PARTNER_ACCOUNT",
            "CAMPAIGN_TEMPLATE",
            "CAMPAIGN_TEMPLATE_STEP",
            "PLAYLIST",
            "CLIP",
            "CAMPAIGN_BUDGET_ITEM",
            "CAMPAIGN_SPEND_ITEM",
            "MIC",
            "CONTENT_AUDIT",
            "CONTENT_AUDIT_PAGE",
            "PLAYLIST_FOLDER",
            "LEAD",
            "ABANDONED_CART",
            "EXTERNAL_WEB_URL",
            "VIEW",
            "VIEW_BLOCK",
            "ROSTER",
            "CART",
            "AUTOMATION_PLATFORM_FLOW_ACTION",
            "SOCIAL_PROFILE",
            "PARTNER_CLIENT",
            "ROSTER_MEMBER",
            "MARKETING_EVENT_ATTENDANCE",
            "ALL_PAGES",
            "AI_FORECAST",
            "CRM_PIPELINES_DUMMY_TYPE",
            "KNOWLEDGE_ARTICLE",
            "PROPERTY_INFO",
            "DATA_PRIVACY_CONSENT",
            "GOAL_TEMPLATE",
            "SCORE_CONFIGURATION",
            "AUDIENCE",
            "PARTNER_CLIENT_REVENUE",
            "AUTOMATION_JOURNEY",
            "COMBO_EVENT_CONFIGURATION",
            "CRM_OBJECTS_DUMMY_TYPE",
            "CASE_STUDY",
            "SERVICE",
            "PODCAST_EPISODE",
            "PARTNER_SERVICE",
            "PROSPECTING_AGENT_CONTACT_ASSIGNMENT",
            "UNKNOWN",
        ]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and object_type not in allowed_values:  # noqa: E501
            raise ValueError("Invalid value for `object_type` ({0}), must be one of {1}".format(object_type, allowed_values))  # noqa: E501

        self._object_type = object_type

    @property
    def invalid_value(self):
        """Gets the invalid_value of this PublicImportError.  # noqa: E501


        :return: The invalid_value of this PublicImportError.  # noqa: E501
        :rtype: str
        """
        return self._invalid_value

    @invalid_value.setter
    def invalid_value(self, invalid_value):
        """Sets the invalid_value of this PublicImportError.


        :param invalid_value: The invalid_value of this PublicImportError.  # noqa: E501
        :type invalid_value: str
        """

        self._invalid_value = invalid_value

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PublicImportError):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PublicImportError):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

# flake8: noqa
"""
    Files

    Upload and manage files.  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

# import models into model package
from hubspot.files.models.collection_response_file import CollectionResponseFile
from hubspot.files.models.collection_response_folder import CollectionResponseFolder
from hubspot.files.models.error import Error
from hubspot.files.models.error_detail import ErrorDetail
from hubspot.files.models.file import File
from hubspot.files.models.file_action_response import FileActionResponse
from hubspot.files.models.file_stat import FileStat
from hubspot.files.models.file_update_input import FileUpdateInput
from hubspot.files.models.folder import Folder
from hubspot.files.models.folder_action_response import FolderActionResponse
from hubspot.files.models.folder_input import FolderInput
from hubspot.files.models.folder_update_input import FolderUpdateInput
from hubspot.files.models.folder_update_input_with_id import FolderUpdateInputWithId
from hubspot.files.models.folder_update_task_locator import FolderUpdateTaskLocator
from hubspot.files.models.import_from_url_input import ImportFromUrlInput
from hubspot.files.models.import_from_url_task_locator import ImportFromUrlTaskLocator
from hubspot.files.models.next_page import NextPage
from hubspot.files.models.paging import Paging
from hubspot.files.models.previous_page import PreviousPage
from hubspot.files.models.signed_url import SignedUrl
from hubspot.files.models.standard_error import StandardError



# coding: utf-8

"""
    Marketing Events

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.marketing.events.configuration import Configuration


class MarketingEventCreateRequestParams(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "start_date_time": "datetime",
        "custom_properties": "list[PropertyValue]",
        "external_account_id": "str",
        "event_cancelled": "bool",
        "event_organizer": "str",
        "event_url": "str",
        "external_event_id": "str",
        "event_description": "str",
        "event_name": "str",
        "event_type": "str",
        "event_completed": "bool",
        "end_date_time": "datetime",
    }

    attribute_map = {
        "start_date_time": "startDateTime",
        "custom_properties": "customProperties",
        "external_account_id": "externalAccountId",
        "event_cancelled": "eventCancelled",
        "event_organizer": "eventOrganizer",
        "event_url": "eventUrl",
        "external_event_id": "externalEventId",
        "event_description": "eventDescription",
        "event_name": "eventName",
        "event_type": "eventType",
        "event_completed": "eventCompleted",
        "end_date_time": "endDateTime",
    }

    def __init__(
        self,
        start_date_time=None,
        custom_properties=None,
        external_account_id=None,
        event_cancelled=None,
        event_organizer=None,
        event_url=None,
        external_event_id=None,
        event_description=None,
        event_name=None,
        event_type=None,
        event_completed=None,
        end_date_time=None,
        local_vars_configuration=None,
    ):  # noqa: E501
        """MarketingEventCreateRequestParams - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._start_date_time = None
        self._custom_properties = None
        self._external_account_id = None
        self._event_cancelled = None
        self._event_organizer = None
        self._event_url = None
        self._external_event_id = None
        self._event_description = None
        self._event_name = None
        self._event_type = None
        self._event_completed = None
        self._end_date_time = None
        self.discriminator = None

        if start_date_time is not None:
            self.start_date_time = start_date_time
        if custom_properties is not None:
            self.custom_properties = custom_properties
        self.external_account_id = external_account_id
        if event_cancelled is not None:
            self.event_cancelled = event_cancelled
        self.event_organizer = event_organizer
        if event_url is not None:
            self.event_url = event_url
        self.external_event_id = external_event_id
        if event_description is not None:
            self.event_description = event_description
        self.event_name = event_name
        if event_type is not None:
            self.event_type = event_type
        if event_completed is not None:
            self.event_completed = event_completed
        if end_date_time is not None:
            self.end_date_time = end_date_time

    @property
    def start_date_time(self):
        """Gets the start_date_time of this MarketingEventCreateRequestParams.  # noqa: E501

        The start date and time of the marketing event.  # noqa: E501

        :return: The start_date_time of this MarketingEventCreateRequestParams.  # noqa: E501
        :rtype: datetime
        """
        return self._start_date_time

    @start_date_time.setter
    def start_date_time(self, start_date_time):
        """Sets the start_date_time of this MarketingEventCreateRequestParams.

        The start date and time of the marketing event.  # noqa: E501

        :param start_date_time: The start_date_time of this MarketingEventCreateRequestParams.  # noqa: E501
        :type start_date_time: datetime
        """

        self._start_date_time = start_date_time

    @property
    def custom_properties(self):
        """Gets the custom_properties of this MarketingEventCreateRequestParams.  # noqa: E501

        A list of PropertyValues. These can be whatever kind of property names and values you want. However, they must already exist on the HubSpot account's definition of the MarketingEvent Object. If they don't they will be filtered out and not set. In order to do this you'll need to create a new PropertyGroup on the HubSpot account's MarketingEvent object for your specific app and create the Custom Property you want to track on that HubSpot account. Do not create any new default properties on the MarketingEvent object as that will apply to all HubSpot accounts.   # noqa: E501

        :return: The custom_properties of this MarketingEventCreateRequestParams.  # noqa: E501
        :rtype: list[PropertyValue]
        """
        return self._custom_properties

    @custom_properties.setter
    def custom_properties(self, custom_properties):
        """Sets the custom_properties of this MarketingEventCreateRequestParams.

        A list of PropertyValues. These can be whatever kind of property names and values you want. However, they must already exist on the HubSpot account's definition of the MarketingEvent Object. If they don't they will be filtered out and not set. In order to do this you'll need to create a new PropertyGroup on the HubSpot account's MarketingEvent object for your specific app and create the Custom Property you want to track on that HubSpot account. Do not create any new default properties on the MarketingEvent object as that will apply to all HubSpot accounts.   # noqa: E501

        :param custom_properties: The custom_properties of this MarketingEventCreateRequestParams.  # noqa: E501
        :type custom_properties: list[PropertyValue]
        """

        self._custom_properties = custom_properties

    @property
    def external_account_id(self):
        """Gets the external_account_id of this MarketingEventCreateRequestParams.  # noqa: E501

        The accountId that is associated with this marketing event in the external event application.  # noqa: E501

        :return: The external_account_id of this MarketingEventCreateRequestParams.  # noqa: E501
        :rtype: str
        """
        return self._external_account_id

    @external_account_id.setter
    def external_account_id(self, external_account_id):
        """Sets the external_account_id of this MarketingEventCreateRequestParams.

        The accountId that is associated with this marketing event in the external event application.  # noqa: E501

        :param external_account_id: The external_account_id of this MarketingEventCreateRequestParams.  # noqa: E501
        :type external_account_id: str
        """
        if self.local_vars_configuration.client_side_validation and external_account_id is None:  # noqa: E501
            raise ValueError("Invalid value for `external_account_id`, must not be `None`")  # noqa: E501

        self._external_account_id = external_account_id

    @property
    def event_cancelled(self):
        """Gets the event_cancelled of this MarketingEventCreateRequestParams.  # noqa: E501

        Indicates if the marketing event has been cancelled.  Defaults to `false`  # noqa: E501

        :return: The event_cancelled of this MarketingEventCreateRequestParams.  # noqa: E501
        :rtype: bool
        """
        return self._event_cancelled

    @event_cancelled.setter
    def event_cancelled(self, event_cancelled):
        """Sets the event_cancelled of this MarketingEventCreateRequestParams.

        Indicates if the marketing event has been cancelled.  Defaults to `false`  # noqa: E501

        :param event_cancelled: The event_cancelled of this MarketingEventCreateRequestParams.  # noqa: E501
        :type event_cancelled: bool
        """

        self._event_cancelled = event_cancelled

    @property
    def event_organizer(self):
        """Gets the event_organizer of this MarketingEventCreateRequestParams.  # noqa: E501

        The name of the organizer of the marketing event.  # noqa: E501

        :return: The event_organizer of this MarketingEventCreateRequestParams.  # noqa: E501
        :rtype: str
        """
        return self._event_organizer

    @event_organizer.setter
    def event_organizer(self, event_organizer):
        """Sets the event_organizer of this MarketingEventCreateRequestParams.

        The name of the organizer of the marketing event.  # noqa: E501

        :param event_organizer: The event_organizer of this MarketingEventCreateRequestParams.  # noqa: E501
        :type event_organizer: str
        """
        if self.local_vars_configuration.client_side_validation and event_organizer is None:  # noqa: E501
            raise ValueError("Invalid value for `event_organizer`, must not be `None`")  # noqa: E501

        self._event_organizer = event_organizer

    @property
    def event_url(self):
        """Gets the event_url of this MarketingEventCreateRequestParams.  # noqa: E501

        A URL in the external event application where the marketing event can be managed.  # noqa: E501

        :return: The event_url of this MarketingEventCreateRequestParams.  # noqa: E501
        :rtype: str
        """
        return self._event_url

    @event_url.setter
    def event_url(self, event_url):
        """Sets the event_url of this MarketingEventCreateRequestParams.

        A URL in the external event application where the marketing event can be managed.  # noqa: E501

        :param event_url: The event_url of this MarketingEventCreateRequestParams.  # noqa: E501
        :type event_url: str
        """

        self._event_url = event_url

    @property
    def external_event_id(self):
        """Gets the external_event_id of this MarketingEventCreateRequestParams.  # noqa: E501

        The id of the marketing event in the external event application.  # noqa: E501

        :return: The external_event_id of this MarketingEventCreateRequestParams.  # noqa: E501
        :rtype: str
        """
        return self._external_event_id

    @external_event_id.setter
    def external_event_id(self, external_event_id):
        """Sets the external_event_id of this MarketingEventCreateRequestParams.

        The id of the marketing event in the external event application.  # noqa: E501

        :param external_event_id: The external_event_id of this MarketingEventCreateRequestParams.  # noqa: E501
        :type external_event_id: str
        """
        if self.local_vars_configuration.client_side_validation and external_event_id is None:  # noqa: E501
            raise ValueError("Invalid value for `external_event_id`, must not be `None`")  # noqa: E501

        self._external_event_id = external_event_id

    @property
    def event_description(self):
        """Gets the event_description of this MarketingEventCreateRequestParams.  # noqa: E501

        The description of the marketing event.  # noqa: E501

        :return: The event_description of this MarketingEventCreateRequestParams.  # noqa: E501
        :rtype: str
        """
        return self._event_description

    @event_description.setter
    def event_description(self, event_description):
        """Sets the event_description of this MarketingEventCreateRequestParams.

        The description of the marketing event.  # noqa: E501

        :param event_description: The event_description of this MarketingEventCreateRequestParams.  # noqa: E501
        :type event_description: str
        """

        self._event_description = event_description

    @property
    def event_name(self):
        """Gets the event_name of this MarketingEventCreateRequestParams.  # noqa: E501

        The name of the marketing event.  # noqa: E501

        :return: The event_name of this MarketingEventCreateRequestParams.  # noqa: E501
        :rtype: str
        """
        return self._event_name

    @event_name.setter
    def event_name(self, event_name):
        """Sets the event_name of this MarketingEventCreateRequestParams.

        The name of the marketing event.  # noqa: E501

        :param event_name: The event_name of this MarketingEventCreateRequestParams.  # noqa: E501
        :type event_name: str
        """
        if self.local_vars_configuration.client_side_validation and event_name is None:  # noqa: E501
            raise ValueError("Invalid value for `event_name`, must not be `None`")  # noqa: E501

        self._event_name = event_name

    @property
    def event_type(self):
        """Gets the event_type of this MarketingEventCreateRequestParams.  # noqa: E501

        Describes what type of event this is.  For example: `WEBINAR`, `CONFERENCE`, `WORKSHOP`  # noqa: E501

        :return: The event_type of this MarketingEventCreateRequestParams.  # noqa: E501
        :rtype: str
        """
        return self._event_type

    @event_type.setter
    def event_type(self, event_type):
        """Sets the event_type of this MarketingEventCreateRequestParams.

        Describes what type of event this is.  For example: `WEBINAR`, `CONFERENCE`, `WORKSHOP`  # noqa: E501

        :param event_type: The event_type of this MarketingEventCreateRequestParams.  # noqa: E501
        :type event_type: str
        """

        self._event_type = event_type

    @property
    def event_completed(self):
        """Gets the event_completed of this MarketingEventCreateRequestParams.  # noqa: E501


        :return: The event_completed of this MarketingEventCreateRequestParams.  # noqa: E501
        :rtype: bool
        """
        return self._event_completed

    @event_completed.setter
    def event_completed(self, event_completed):
        """Sets the event_completed of this MarketingEventCreateRequestParams.


        :param event_completed: The event_completed of this MarketingEventCreateRequestParams.  # noqa: E501
        :type event_completed: bool
        """

        self._event_completed = event_completed

    @property
    def end_date_time(self):
        """Gets the end_date_time of this MarketingEventCreateRequestParams.  # noqa: E501

        The end date and time of the marketing event.  # noqa: E501

        :return: The end_date_time of this MarketingEventCreateRequestParams.  # noqa: E501
        :rtype: datetime
        """
        return self._end_date_time

    @end_date_time.setter
    def end_date_time(self, end_date_time):
        """Sets the end_date_time of this MarketingEventCreateRequestParams.

        The end date and time of the marketing event.  # noqa: E501

        :param end_date_time: The end_date_time of this MarketingEventCreateRequestParams.  # noqa: E501
        :type end_date_time: datetime
        """

        self._end_date_time = end_date_time

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MarketingEventCreateRequestParams):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, MarketingEventCreateRequestParams):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

# flake8: noqa
"""
    Cms Content Audit

    Use this endpoint to query audit logs of CMS changes that occurred on your HubSpot account.  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

# import models into model package
from hubspot.cms.audit_logs.models.collection_response_public_audit_log import CollectionResponsePublicAuditLog
from hubspot.cms.audit_logs.models.error import Error
from hubspot.cms.audit_logs.models.error_detail import ErrorDetail
from hubspot.cms.audit_logs.models.next_page import NextPage
from hubspot.cms.audit_logs.models.paging import Paging
from hubspot.cms.audit_logs.models.previous_page import PreviousPage
from hubspot.cms.audit_logs.models.public_audit_log import PublicAuditLog



# coding: utf-8

"""
    Contacts

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.crm.contacts.configuration import Configuration


class Filter(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"high_value": "str", "property_name": "str", "values": "list[str]", "value": "str", "operator": "str"}

    attribute_map = {"high_value": "highValue", "property_name": "propertyName", "values": "values", "value": "value", "operator": "operator"}

    def __init__(self, high_value=None, property_name=None, values=None, value=None, operator=None, local_vars_configuration=None):  # noqa: E501
        """Filter - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._high_value = None
        self._property_name = None
        self._values = None
        self._value = None
        self._operator = None
        self.discriminator = None

        if high_value is not None:
            self.high_value = high_value
        self.property_name = property_name
        if values is not None:
            self.values = values
        if value is not None:
            self.value = value
        self.operator = operator

    @property
    def high_value(self):
        """Gets the high_value of this Filter.  # noqa: E501


        :return: The high_value of this Filter.  # noqa: E501
        :rtype: str
        """
        return self._high_value

    @high_value.setter
    def high_value(self, high_value):
        """Sets the high_value of this Filter.


        :param high_value: The high_value of this Filter.  # noqa: E501
        :type high_value: str
        """

        self._high_value = high_value

    @property
    def property_name(self):
        """Gets the property_name of this Filter.  # noqa: E501


        :return: The property_name of this Filter.  # noqa: E501
        :rtype: str
        """
        return self._property_name

    @property_name.setter
    def property_name(self, property_name):
        """Sets the property_name of this Filter.


        :param property_name: The property_name of this Filter.  # noqa: E501
        :type property_name: str
        """
        if self.local_vars_configuration.client_side_validation and property_name is None:  # noqa: E501
            raise ValueError("Invalid value for `property_name`, must not be `None`")  # noqa: E501

        self._property_name = property_name

    @property
    def values(self):
        """Gets the values of this Filter.  # noqa: E501


        :return: The values of this Filter.  # noqa: E501
        :rtype: list[str]
        """
        return self._values

    @values.setter
    def values(self, values):
        """Sets the values of this Filter.


        :param values: The values of this Filter.  # noqa: E501
        :type values: list[str]
        """

        self._values = values

    @property
    def value(self):
        """Gets the value of this Filter.  # noqa: E501


        :return: The value of this Filter.  # noqa: E501
        :rtype: str
        """
        return self._value

    @value.setter
    def value(self, value):
        """Sets the value of this Filter.


        :param value: The value of this Filter.  # noqa: E501
        :type value: str
        """

        self._value = value

    @property
    def operator(self):
        """Gets the operator of this Filter.  # noqa: E501

        null  # noqa: E501

        :return: The operator of this Filter.  # noqa: E501
        :rtype: str
        """
        return self._operator

    @operator.setter
    def operator(self, operator):
        """Sets the operator of this Filter.

        null  # noqa: E501

        :param operator: The operator of this Filter.  # noqa: E501
        :type operator: str
        """
        if self.local_vars_configuration.client_side_validation and operator is None:  # noqa: E501
            raise ValueError("Invalid value for `operator`, must not be `None`")  # noqa: E501
        allowed_values = ["EQ", "NEQ", "LT", "LTE", "GT", "GTE", "BETWEEN", "IN", "NOT_IN", "HAS_PROPERTY", "NOT_HAS_PROPERTY", "CONTAINS_TOKEN", "NOT_CONTAINS_TOKEN"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and operator not in allowed_values:  # noqa: E501
            raise ValueError("Invalid value for `operator` ({0}), must be one of {1}".format(operator, allowed_values))  # noqa: E501

        self._operator = operator

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Filter):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Filter):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Communication Preferences Subscriptions

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.communication_preferences.configuration import Configuration


class ErrorDetail(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"sub_category": "str", "code": "str", "_in": "str", "context": "dict[str, list[str]]", "message": "str"}

    attribute_map = {"sub_category": "subCategory", "code": "code", "_in": "in", "context": "context", "message": "message"}

    def __init__(self, sub_category=None, code=None, _in=None, context=None, message=None, local_vars_configuration=None):  # noqa: E501
        """ErrorDetail - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._sub_category = None
        self._code = None
        self.__in = None
        self._context = None
        self._message = None
        self.discriminator = None

        if sub_category is not None:
            self.sub_category = sub_category
        if code is not None:
            self.code = code
        if _in is not None:
            self._in = _in
        if context is not None:
            self.context = context
        self.message = message

    @property
    def sub_category(self):
        """Gets the sub_category of this ErrorDetail.  # noqa: E501

        A specific category that contains more specific detail about the error  # noqa: E501

        :return: The sub_category of this ErrorDetail.  # noqa: E501
        :rtype: str
        """
        return self._sub_category

    @sub_category.setter
    def sub_category(self, sub_category):
        """Sets the sub_category of this ErrorDetail.

        A specific category that contains more specific detail about the error  # noqa: E501

        :param sub_category: The sub_category of this ErrorDetail.  # noqa: E501
        :type sub_category: str
        """

        self._sub_category = sub_category

    @property
    def code(self):
        """Gets the code of this ErrorDetail.  # noqa: E501

        The status code associated with the error detail  # noqa: E501

        :return: The code of this ErrorDetail.  # noqa: E501
        :rtype: str
        """
        return self._code

    @code.setter
    def code(self, code):
        """Sets the code of this ErrorDetail.

        The status code associated with the error detail  # noqa: E501

        :param code: The code of this ErrorDetail.  # noqa: E501
        :type code: str
        """

        self._code = code

    @property
    def _in(self):
        """Gets the _in of this ErrorDetail.  # noqa: E501

        The name of the field or parameter in which the error was found.  # noqa: E501

        :return: The _in of this ErrorDetail.  # noqa: E501
        :rtype: str
        """
        return self.__in

    @_in.setter
    def _in(self, _in):
        """Sets the _in of this ErrorDetail.

        The name of the field or parameter in which the error was found.  # noqa: E501

        :param _in: The _in of this ErrorDetail.  # noqa: E501
        :type _in: str
        """

        self.__in = _in

    @property
    def context(self):
        """Gets the context of this ErrorDetail.  # noqa: E501

        Context about the error condition  # noqa: E501

        :return: The context of this ErrorDetail.  # noqa: E501
        :rtype: dict[str, list[str]]
        """
        return self._context

    @context.setter
    def context(self, context):
        """Sets the context of this ErrorDetail.

        Context about the error condition  # noqa: E501

        :param context: The context of this ErrorDetail.  # noqa: E501
        :type context: dict[str, list[str]]
        """

        self._context = context

    @property
    def message(self):
        """Gets the message of this ErrorDetail.  # noqa: E501

        A human readable message describing the error along with remediation steps where appropriate  # noqa: E501

        :return: The message of this ErrorDetail.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this ErrorDetail.

        A human readable message describing the error along with remediation steps where appropriate  # noqa: E501

        :param message: The message of this ErrorDetail.  # noqa: E501
        :type message: str
        """
        if self.local_vars_configuration.client_side_validation and message is None:  # noqa: E501
            raise ValueError("Invalid value for `message`, must not be `None`")  # noqa: E501

        self._message = message

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ErrorDetail):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ErrorDetail):
            return True

        return self.to_dict() != other.to_dict()



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from hubspot.crm.properties.api.batch_api import BatchApi
from hubspot.crm.properties.api.core_api import CoreApi
from hubspot.crm.properties.api.groups_api import GroupsApi



import hubspot.communication_preferences as api_client
from ..discovery_base import DiscoveryBase


class Discovery(DiscoveryBase):
    @property
    def definition_api(self) -> api_client.DefinitionApi:
        return self._configure_api_client(api_client, "DefinitionApi")

    @property
    def status_api(self) -> api_client.StatusApi:
        return self._configure_api_client(api_client, "StatusApi")



# coding: utf-8

"""
    Marketing Emails

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.marketing.emails.configuration import Configuration


class EmailCreateRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "feedback_survey_id": "str",
        "rss_data": "PublicRssEmailDetails",
        "subject": "str",
        "testing": "PublicEmailTestingDetails",
        "publish_date": "datetime",
        "language": "str",
        "business_unit_id": "int",
        "content": "PublicEmailContent",
        "webversion": "PublicWebversionDetails",
        "archived": "bool",
        "subscription_details": "PublicEmailSubscriptionDetails",
        "active_domain": "str",
        "name": "str",
        "campaign": "str",
        "_from": "PublicEmailFromDetails",
        "jitter_send_time": "bool",
        "state": "str",
        "to": "PublicEmailToDetails",
        "subcategory": "str",
        "send_on_publish": "bool",
    }

    attribute_map = {
        "feedback_survey_id": "feedbackSurveyId",
        "rss_data": "rssData",
        "subject": "subject",
        "testing": "testing",
        "publish_date": "publishDate",
        "language": "language",
        "business_unit_id": "businessUnitId",
        "content": "content",
        "webversion": "webversion",
        "archived": "archived",
        "subscription_details": "subscriptionDetails",
        "active_domain": "activeDomain",
        "name": "name",
        "campaign": "campaign",
        "_from": "from",
        "jitter_send_time": "jitterSendTime",
        "state": "state",
        "to": "to",
        "subcategory": "subcategory",
        "send_on_publish": "sendOnPublish",
    }

    def __init__(
        self,
        feedback_survey_id=None,
        rss_data=None,
        subject=None,
        testing=None,
        publish_date=None,
        language=None,
        business_unit_id=None,
        content=None,
        webversion=None,
        archived=None,
        subscription_details=None,
        active_domain=None,
        name=None,
        campaign=None,
        _from=None,
        jitter_send_time=None,
        state=None,
        to=None,
        subcategory=None,
        send_on_publish=None,
        local_vars_configuration=None,
    ):  # noqa: E501
        """EmailCreateRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._feedback_survey_id = None
        self._rss_data = None
        self._subject = None
        self._testing = None
        self._publish_date = None
        self._language = None
        self._business_unit_id = None
        self._content = None
        self._webversion = None
        self._archived = None
        self._subscription_details = None
        self._active_domain = None
        self._name = None
        self._campaign = None
        self.__from = None
        self._jitter_send_time = None
        self._state = None
        self._to = None
        self._subcategory = None
        self._send_on_publish = None
        self.discriminator = None

        if feedback_survey_id is not None:
            self.feedback_survey_id = feedback_survey_id
        if rss_data is not None:
            self.rss_data = rss_data
        if subject is not None:
            self.subject = subject
        if testing is not None:
            self.testing = testing
        if publish_date is not None:
            self.publish_date = publish_date
        if language is not None:
            self.language = language
        if business_unit_id is not None:
            self.business_unit_id = business_unit_id
        if content is not None:
            self.content = content
        if webversion is not None:
            self.webversion = webversion
        if archived is not None:
            self.archived = archived
        if subscription_details is not None:
            self.subscription_details = subscription_details
        if active_domain is not None:
            self.active_domain = active_domain
        self.name = name
        if campaign is not None:
            self.campaign = campaign
        if _from is not None:
            self._from = _from
        if jitter_send_time is not None:
            self.jitter_send_time = jitter_send_time
        if state is not None:
            self.state = state
        if to is not None:
            self.to = to
        if subcategory is not None:
            self.subcategory = subcategory
        if send_on_publish is not None:
            self.send_on_publish = send_on_publish

    @property
    def feedback_survey_id(self):
        """Gets the feedback_survey_id of this EmailCreateRequest.  # noqa: E501

        The ID of the feedback survey linked to the email.  # noqa: E501

        :return: The feedback_survey_id of this EmailCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._feedback_survey_id

    @feedback_survey_id.setter
    def feedback_survey_id(self, feedback_survey_id):
        """Sets the feedback_survey_id of this EmailCreateRequest.

        The ID of the feedback survey linked to the email.  # noqa: E501

        :param feedback_survey_id: The feedback_survey_id of this EmailCreateRequest.  # noqa: E501
        :type feedback_survey_id: str
        """

        self._feedback_survey_id = feedback_survey_id

    @property
    def rss_data(self):
        """Gets the rss_data of this EmailCreateRequest.  # noqa: E501


        :return: The rss_data of this EmailCreateRequest.  # noqa: E501
        :rtype: PublicRssEmailDetails
        """
        return self._rss_data

    @rss_data.setter
    def rss_data(self, rss_data):
        """Sets the rss_data of this EmailCreateRequest.


        :param rss_data: The rss_data of this EmailCreateRequest.  # noqa: E501
        :type rss_data: PublicRssEmailDetails
        """

        self._rss_data = rss_data

    @property
    def subject(self):
        """Gets the subject of this EmailCreateRequest.  # noqa: E501

        The subject of the email.  # noqa: E501

        :return: The subject of this EmailCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._subject

    @subject.setter
    def subject(self, subject):
        """Sets the subject of this EmailCreateRequest.

        The subject of the email.  # noqa: E501

        :param subject: The subject of this EmailCreateRequest.  # noqa: E501
        :type subject: str
        """

        self._subject = subject

    @property
    def testing(self):
        """Gets the testing of this EmailCreateRequest.  # noqa: E501


        :return: The testing of this EmailCreateRequest.  # noqa: E501
        :rtype: PublicEmailTestingDetails
        """
        return self._testing

    @testing.setter
    def testing(self, testing):
        """Sets the testing of this EmailCreateRequest.


        :param testing: The testing of this EmailCreateRequest.  # noqa: E501
        :type testing: PublicEmailTestingDetails
        """

        self._testing = testing

    @property
    def publish_date(self):
        """Gets the publish_date of this EmailCreateRequest.  # noqa: E501

        The date and time the email is scheduled for, in ISO8601 representation. This is only used in local time or scheduled emails.  # noqa: E501

        :return: The publish_date of this EmailCreateRequest.  # noqa: E501
        :rtype: datetime
        """
        return self._publish_date

    @publish_date.setter
    def publish_date(self, publish_date):
        """Sets the publish_date of this EmailCreateRequest.

        The date and time the email is scheduled for, in ISO8601 representation. This is only used in local time or scheduled emails.  # noqa: E501

        :param publish_date: The publish_date of this EmailCreateRequest.  # noqa: E501
        :type publish_date: datetime
        """

        self._publish_date = publish_date

    @property
    def language(self):
        """Gets the language of this EmailCreateRequest.  # noqa: E501


        :return: The language of this EmailCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._language

    @language.setter
    def language(self, language):
        """Sets the language of this EmailCreateRequest.


        :param language: The language of this EmailCreateRequest.  # noqa: E501
        :type language: str
        """
        allowed_values = [
            "af",
            "af-na",
            "af-za",
            "agq",
            "agq-cm",
            "ak",
            "ak-gh",
            "am",
            "am-et",
            "ann",
            "ann-ng",
            "ar",
            "ar-001",
            "ar-ae",
            "ar-bh",
            "ar-dj",
            "ar-dz",
            "ar-eg",
            "ar-eh",
            "ar-er",
            "ar-il",
            "ar-iq",
            "ar-jo",
            "ar-km",
            "ar-kw",
            "ar-lb",
            "ar-ly",
            "ar-ma",
            "ar-mr",
            "ar-om",
            "ar-ps",
            "ar-qa",
            "ar-sa",
            "ar-sd",
            "ar-so",
            "ar-ss",
            "ar-sy",
            "ar-td",
            "ar-tn",
            "ar-ye",
            "as",
            "asa",
            "asa-tz",
            "ast",
            "ast-es",
            "as-in",
            "az",
            "az-az",
            "bas",
            "bas-cm",
            "be",
            "bem",
            "bem-zm",
            "bez",
            "bez-tz",
            "be-by",
            "bg",
            "bgc",
            "bgc-in",
            "bg-bg",
            "bho",
            "bho-in",
            "bm",
            "bm-ml",
            "bn",
            "bn-bd",
            "bn-in",
            "bo",
            "bo-cn",
            "bo-in",
            "br",
            "brx",
            "brx-in",
            "br-fr",
            "bs",
            "bs-ba",
            "ca",
            "ca-ad",
            "ca-es",
            "ca-fr",
            "ca-it",
            "ccp",
            "ccp-bd",
            "ccp-in",
            "ce",
            "ceb",
            "ceb-ph",
            "ce-ru",
            "cgg",
            "cgg-ug",
            "chr",
            "chr-us",
            "ckb",
            "ckb-iq",
            "ckb-ir",
            "cs",
            "cs-cz",
            "cu",
            "cu-ru",
            "cv",
            "cv-ru",
            "cy",
            "cy-gb",
            "da",
            "dav",
            "dav-ke",
            "da-dk",
            "da-gl",
            "de",
            "de-at",
            "de-be",
            "de-ch",
            "de-de",
            "de-gr",
            "de-it",
            "de-li",
            "de-lu",
            "dje",
            "dje-ne",
            "doi",
            "doi-in",
            "dsb",
            "dsb-de",
            "dua",
            "dua-cm",
            "dyo",
            "dyo-sn",
            "dz",
            "dz-bt",
            "ebu",
            "ebu-ke",
            "ee",
            "ee-gh",
            "ee-tg",
            "el",
            "el-cy",
            "el-gr",
            "en",
            "en-001",
            "en-150",
            "en-ae",
            "en-ag",
            "en-ai",
            "en-as",
            "en-at",
            "en-au",
            "en-bb",
            "en-be",
            "en-bi",
            "en-bm",
            "en-bs",
            "en-bw",
            "en-bz",
            "en-ca",
            "en-cc",
            "en-ch",
            "en-ck",
            "en-cm",
            "en-cn",
            "en-cx",
            "en-cy",
            "en-de",
            "en-dg",
            "en-dk",
            "en-dm",
            "en-ee",
            "en-er",
            "en-fi",
            "en-fj",
            "en-fk",
            "en-fm",
            "en-fr",
            "en-gb",
            "en-gd",
            "en-gg",
            "en-gh",
            "en-gi",
            "en-gm",
            "en-gu",
            "en-gy",
            "en-hk",
            "en-ie",
            "en-il",
            "en-im",
            "en-in",
            "en-io",
            "en-je",
            "en-jm",
            "en-ke",
            "en-ki",
            "en-kn",
            "en-ky",
            "en-lc",
            "en-lr",
            "en-ls",
            "en-lu",
            "en-mg",
            "en-mh",
            "en-mo",
            "en-mp",
            "en-ms",
            "en-mt",
            "en-mu",
            "en-mv",
            "en-mw",
            "en-mx",
            "en-my",
            "en-na",
            "en-nf",
            "en-ng",
            "en-nl",
            "en-nr",
            "en-nu",
            "en-nz",
            "en-pg",
            "en-ph",
            "en-pk",
            "en-pn",
            "en-pr",
            "en-pw",
            "en-rw",
            "en-sb",
            "en-sc",
            "en-sd",
            "en-se",
            "en-sg",
            "en-sh",
            "en-si",
            "en-sl",
            "en-ss",
            "en-sx",
            "en-sz",
            "en-tc",
            "en-tk",
            "en-to",
            "en-tt",
            "en-tv",
            "en-tz",
            "en-ug",
            "en-um",
            "en-us",
            "en-vc",
            "en-vg",
            "en-vi",
            "en-vu",
            "en-ws",
            "en-za",
            "en-zm",
            "en-zw",
            "eo",
            "eo-001",
            "es",
            "es-419",
            "es-ar",
            "es-bo",
            "es-br",
            "es-bz",
            "es-cl",
            "es-co",
            "es-cr",
            "es-cu",
            "es-do",
            "es-ea",
            "es-ec",
            "es-es",
            "es-gq",
            "es-gt",
            "es-hn",
            "es-ic",
            "es-mx",
            "es-ni",
            "es-pa",
            "es-pe",
            "es-ph",
            "es-pr",
            "es-py",
            "es-sv",
            "es-us",
            "es-uy",
            "es-ve",
            "et",
            "et-ee",
            "eu",
            "eu-es",
            "ewo",
            "ewo-cm",
            "fa",
            "fa-af",
            "fa-ir",
            "ff",
            "ff-bf",
            "ff-cm",
            "ff-gh",
            "ff-gm",
            "ff-gn",
            "ff-gw",
            "ff-lr",
            "ff-mr",
            "ff-ne",
            "ff-ng",
            "ff-sl",
            "ff-sn",
            "fi",
            "fil",
            "fil-ph",
            "fi-fi",
            "fo",
            "fo-dk",
            "fo-fo",
            "fr",
            "frr",
            "frr-de",
            "fr-be",
            "fr-bf",
            "fr-bi",
            "fr-bj",
            "fr-bl",
            "fr-ca",
            "fr-cd",
            "fr-cf",
            "fr-cg",
            "fr-ch",
            "fr-ci",
            "fr-cm",
            "fr-dj",
            "fr-dz",
            "fr-fr",
            "fr-ga",
            "fr-gf",
            "fr-gn",
            "fr-gp",
            "fr-gq",
            "fr-ht",
            "fr-km",
            "fr-lu",
            "fr-ma",
            "fr-mc",
            "fr-mf",
            "fr-mg",
            "fr-ml",
            "fr-mq",
            "fr-mr",
            "fr-mu",
            "fr-nc",
            "fr-ne",
            "fr-pf",
            "fr-pm",
            "fr-re",
            "fr-rw",
            "fr-sc",
            "fr-sn",
            "fr-sy",
            "fr-td",
            "fr-tg",
            "fr-tn",
            "fr-vu",
            "fr-wf",
            "fr-yt",
            "fur",
            "fur-it",
            "fy",
            "fy-nl",
            "ga",
            "ga-gb",
            "ga-ie",
            "gd",
            "gd-gb",
            "gl",
            "gl-es",
            "gsw",
            "gsw-ch",
            "gsw-fr",
            "gsw-li",
            "gu",
            "guz",
            "guz-ke",
            "gu-in",
            "gv",
            "gv-im",
            "ha",
            "haw",
            "haw-us",
            "ha-gh",
            "ha-ne",
            "ha-ng",
            "he",
            "hi",
            "hi-in",
            "hr",
            "hr-ba",
            "hr-hr",
            "hsb",
            "hsb-de",
            "hu",
            "hu-hu",
            "hy",
            "hy-am",
            "ia",
            "ia-001",
            "id",
            "ig",
            "ig-ng",
            "ii",
            "ii-cn",
            "id-id",
            "is",
            "is-is",
            "it",
            "it-ch",
            "it-it",
            "it-sm",
            "it-va",
            "he-il",
            "ja",
            "ja-jp",
            "jgo",
            "jgo-cm",
            "yi",
            "yi-001",
            "jmc",
            "jmc-tz",
            "jv",
            "jv-id",
            "ka",
            "kab",
            "kab-dz",
            "kam",
            "kam-ke",
            "ka-ge",
            "kde",
            "kde-tz",
            "kea",
            "kea-cv",
            "kgp",
            "kgp-br",
            "khq",
            "khq-ml",
            "ki",
            "ki-ke",
            "kk",
            "kkj",
            "kkj-cm",
            "kk-kz",
            "kl",
            "kln",
            "kln-ke",
            "kl-gl",
            "km",
            "km-kh",
            "kn",
            "kn-in",
            "ko",
            "kok",
            "kok-in",
            "ko-kp",
            "ko-kr",
            "ks",
            "ksb",
            "ksb-tz",
            "ksf",
            "ksf-cm",
            "ksh",
            "ksh-de",
            "ks-in",
            "ku",
            "ku-tr",
            "kw",
            "kw-gb",
            "ky",
            "ky-kg",
            "lag",
            "lag-tz",
            "lb",
            "lb-lu",
            "lg",
            "lg-ug",
            "lkt",
            "lkt-us",
            "ln",
            "ln-ao",
            "ln-cd",
            "ln-cf",
            "ln-cg",
            "lo",
            "lo-la",
            "lrc",
            "lrc-iq",
            "lrc-ir",
            "lt",
            "lt-lt",
            "lu",
            "luo",
            "luo-ke",
            "luy",
            "luy-ke",
            "lu-cd",
            "lv",
            "lv-lv",
            "mai",
            "mai-in",
            "mas",
            "mas-ke",
            "mas-tz",
            "mdf",
            "mdf-ru",
            "mer",
            "mer-ke",
            "mfe",
            "mfe-mu",
            "mg",
            "mgh",
            "mgh-mz",
            "mgo",
            "mgo-cm",
            "mg-mg",
            "mi",
            "mi-nz",
            "mk",
            "mk-mk",
            "ml",
            "ml-in",
            "mn",
            "mni",
            "mni-in",
            "mn-mn",
            "mr",
            "mr-in",
            "ms",
            "ms-bn",
            "ms-id",
            "ms-my",
            "ms-sg",
            "mt",
            "mt-mt",
            "mua",
            "mua-cm",
            "my",
            "my-mm",
            "mzn",
            "mzn-ir",
            "naq",
            "naq-na",
            "nb",
            "nb-no",
            "nb-sj",
            "nd",
            "nds",
            "nds-de",
            "nds-nl",
            "nd-zw",
            "ne",
            "ne-in",
            "ne-np",
            "nl",
            "nl-aw",
            "nl-be",
            "nl-bq",
            "nl-ch",
            "nl-cw",
            "nl-lu",
            "nl-nl",
            "nl-sr",
            "nl-sx",
            "nmg",
            "nmg-cm",
            "nn",
            "nnh",
            "nnh-cm",
            "nn-no",
            "no",
            "no-no",
            "nus",
            "nus-ss",
            "nyn",
            "nyn-ug",
            "oc",
            "oc-es",
            "oc-fr",
            "om",
            "om-et",
            "om-ke",
            "or",
            "or-in",
            "os",
            "os-ge",
            "os-ru",
            "pa",
            "pa-in",
            "pa-pk",
            "pcm",
            "pcm-ng",
            "pis",
            "pis-sb",
            "pl",
            "pl-pl",
            "prg",
            "prg-001",
            "ps",
            "ps-af",
            "ps-pk",
            "pt",
            "pt-ao",
            "pt-br",
            "pt-ch",
            "pt-cv",
            "pt-gq",
            "pt-gw",
            "pt-lu",
            "pt-mo",
            "pt-mz",
            "pt-pt",
            "pt-st",
            "pt-tl",
            "qu",
            "qu-bo",
            "qu-ec",
            "qu-pe",
            "raj",
            "raj-in",
            "rm",
            "rm-ch",
            "rn",
            "rn-bi",
            "ro",
            "rof",
            "rof-tz",
            "ro-md",
            "ro-ro",
            "ru",
            "ru-by",
            "ru-kg",
            "ru-kz",
            "ru-md",
            "ru-ru",
            "ru-ua",
            "rw",
            "rwk",
            "rwk-tz",
            "rw-rw",
            "sa",
            "sah",
            "sah-ru",
            "saq",
            "saq-ke",
            "sat",
            "sat-in",
            "sa-in",
            "sbp",
            "sbp-tz",
            "sc",
            "sc-it",
            "sd",
            "sd-in",
            "sd-pk",
            "se",
            "seh",
            "seh-mz",
            "ses",
            "ses-ml",
            "se-fi",
            "se-no",
            "se-se",
            "sg",
            "sg-cf",
            "shi",
            "shi-ma",
            "si",
            "si-lk",
            "sk",
            "sk-sk",
            "sl",
            "sl-si",
            "smn",
            "smn-fi",
            "sms",
            "sms-fi",
            "sn",
            "sn-zw",
            "so",
            "so-dj",
            "so-et",
            "so-ke",
            "so-so",
            "sq",
            "sq-al",
            "sq-mk",
            "sq-xk",
            "sr",
            "sr-ba",
            "sr-cs",
            "sr-me",
            "sr-rs",
            "sr-xk",
            "su",
            "su-id",
            "sv",
            "sv-ax",
            "sv-fi",
            "sv-se",
            "sw",
            "sw-cd",
            "sw-ke",
            "sw-tz",
            "sw-ug",
            "sy",
            "ta",
            "ta-in",
            "ta-lk",
            "ta-my",
            "ta-sg",
            "te",
            "teo",
            "teo-ke",
            "teo-ug",
            "te-in",
            "tg",
            "tg-tj",
            "th",
            "th-th",
            "ti",
            "ti-er",
            "ti-et",
            "tk",
            "tk-tm",
            "tl",
            "to",
            "tok",
            "tok-001",
            "to-to",
            "tr",
            "tr-cy",
            "tr-tr",
            "tt",
            "tt-ru",
            "twq",
            "twq-ne",
            "tzm",
            "tzm-ma",
            "ug",
            "ug-cn",
            "uk",
            "uk-ua",
            "ur",
            "ur-in",
            "ur-pk",
            "uz",
            "uz-af",
            "uz-uz",
            "vai",
            "vai-lr",
            "vi",
            "vi-vn",
            "vo",
            "vo-001",
            "vun",
            "vun-tz",
            "wae",
            "wae-ch",
            "wo",
            "wo-sn",
            "xh",
            "xh-za",
            "xog",
            "xog-ug",
            "yav",
            "yav-cm",
            "yo",
            "yo-bj",
            "yo-ng",
            "yrl",
            "yrl-br",
            "yrl-co",
            "yrl-ve",
            "yue",
            "yue-cn",
            "yue-hk",
            "zgh",
            "zgh-ma",
            "zh",
            "zh-cn",
            "zh-hans",
            "zh-hant",
            "zh-hk",
            "zh-mo",
            "zh-sg",
            "zh-tw",
            "zu",
            "zu-za",
        ]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and language not in allowed_values:  # noqa: E501
            raise ValueError("Invalid value for `language` ({0}), must be one of {1}".format(language, allowed_values))  # noqa: E501

        self._language = language

    @property
    def business_unit_id(self):
        """Gets the business_unit_id of this EmailCreateRequest.  # noqa: E501


        :return: The business_unit_id of this EmailCreateRequest.  # noqa: E501
        :rtype: int
        """
        return self._business_unit_id

    @business_unit_id.setter
    def business_unit_id(self, business_unit_id):
        """Sets the business_unit_id of this EmailCreateRequest.


        :param business_unit_id: The business_unit_id of this EmailCreateRequest.  # noqa: E501
        :type business_unit_id: int
        """

        self._business_unit_id = business_unit_id

    @property
    def content(self):
        """Gets the content of this EmailCreateRequest.  # noqa: E501


        :return: The content of this EmailCreateRequest.  # noqa: E501
        :rtype: PublicEmailContent
        """
        return self._content

    @content.setter
    def content(self, content):
        """Sets the content of this EmailCreateRequest.


        :param content: The content of this EmailCreateRequest.  # noqa: E501
        :type content: PublicEmailContent
        """

        self._content = content

    @property
    def webversion(self):
        """Gets the webversion of this EmailCreateRequest.  # noqa: E501


        :return: The webversion of this EmailCreateRequest.  # noqa: E501
        :rtype: PublicWebversionDetails
        """
        return self._webversion

    @webversion.setter
    def webversion(self, webversion):
        """Sets the webversion of this EmailCreateRequest.


        :param webversion: The webversion of this EmailCreateRequest.  # noqa: E501
        :type webversion: PublicWebversionDetails
        """

        self._webversion = webversion

    @property
    def archived(self):
        """Gets the archived of this EmailCreateRequest.  # noqa: E501

        Determines if the email is archived or not.  # noqa: E501

        :return: The archived of this EmailCreateRequest.  # noqa: E501
        :rtype: bool
        """
        return self._archived

    @archived.setter
    def archived(self, archived):
        """Sets the archived of this EmailCreateRequest.

        Determines if the email is archived or not.  # noqa: E501

        :param archived: The archived of this EmailCreateRequest.  # noqa: E501
        :type archived: bool
        """

        self._archived = archived

    @property
    def subscription_details(self):
        """Gets the subscription_details of this EmailCreateRequest.  # noqa: E501


        :return: The subscription_details of this EmailCreateRequest.  # noqa: E501
        :rtype: PublicEmailSubscriptionDetails
        """
        return self._subscription_details

    @subscription_details.setter
    def subscription_details(self, subscription_details):
        """Sets the subscription_details of this EmailCreateRequest.


        :param subscription_details: The subscription_details of this EmailCreateRequest.  # noqa: E501
        :type subscription_details: PublicEmailSubscriptionDetails
        """

        self._subscription_details = subscription_details

    @property
    def active_domain(self):
        """Gets the active_domain of this EmailCreateRequest.  # noqa: E501

        The active domain of the email.  # noqa: E501

        :return: The active_domain of this EmailCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._active_domain

    @active_domain.setter
    def active_domain(self, active_domain):
        """Sets the active_domain of this EmailCreateRequest.

        The active domain of the email.  # noqa: E501

        :param active_domain: The active_domain of this EmailCreateRequest.  # noqa: E501
        :type active_domain: str
        """

        self._active_domain = active_domain

    @property
    def name(self):
        """Gets the name of this EmailCreateRequest.  # noqa: E501

        The name of the email, as displayed on the email dashboard.  # noqa: E501

        :return: The name of this EmailCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this EmailCreateRequest.

        The name of the email, as displayed on the email dashboard.  # noqa: E501

        :param name: The name of this EmailCreateRequest.  # noqa: E501
        :type name: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def campaign(self):
        """Gets the campaign of this EmailCreateRequest.  # noqa: E501

        The ID of the campaign this email is associated to.  # noqa: E501

        :return: The campaign of this EmailCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._campaign

    @campaign.setter
    def campaign(self, campaign):
        """Sets the campaign of this EmailCreateRequest.

        The ID of the campaign this email is associated to.  # noqa: E501

        :param campaign: The campaign of this EmailCreateRequest.  # noqa: E501
        :type campaign: str
        """

        self._campaign = campaign

    @property
    def _from(self):
        """Gets the _from of this EmailCreateRequest.  # noqa: E501


        :return: The _from of this EmailCreateRequest.  # noqa: E501
        :rtype: PublicEmailFromDetails
        """
        return self.__from

    @_from.setter
    def _from(self, _from):
        """Sets the _from of this EmailCreateRequest.


        :param _from: The _from of this EmailCreateRequest.  # noqa: E501
        :type _from: PublicEmailFromDetails
        """

        self.__from = _from

    @property
    def jitter_send_time(self):
        """Gets the jitter_send_time of this EmailCreateRequest.  # noqa: E501


        :return: The jitter_send_time of this EmailCreateRequest.  # noqa: E501
        :rtype: bool
        """
        return self._jitter_send_time

    @jitter_send_time.setter
    def jitter_send_time(self, jitter_send_time):
        """Sets the jitter_send_time of this EmailCreateRequest.


        :param jitter_send_time: The jitter_send_time of this EmailCreateRequest.  # noqa: E501
        :type jitter_send_time: bool
        """

        self._jitter_send_time = jitter_send_time

    @property
    def state(self):
        """Gets the state of this EmailCreateRequest.  # noqa: E501

        The email state.  # noqa: E501

        :return: The state of this EmailCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this EmailCreateRequest.

        The email state.  # noqa: E501

        :param state: The state of this EmailCreateRequest.  # noqa: E501
        :type state: str
        """
        allowed_values = [
            "AUTOMATED",
            "AUTOMATED_DRAFT",
            "AUTOMATED_SENDING",
            "AUTOMATED_FOR_FORM",
            "AUTOMATED_FOR_FORM_BUFFER",
            "AUTOMATED_FOR_FORM_DRAFT",
            "AUTOMATED_FOR_FORM_LEGACY",
            "BLOG_EMAIL_DRAFT",
            "BLOG_EMAIL_PUBLISHED",
            "DRAFT",
            "DRAFT_AB",
            "DRAFT_AB_VARIANT",
            "ERROR",
            "LOSER_AB_VARIANT",
            "PAGE_STUB",
            "PRE_PROCESSING",
            "PROCESSING",
            "PUBLISHED",
            "PUBLISHED_AB",
            "PUBLISHED_AB_VARIANT",
            "PUBLISHED_OR_SCHEDULED",
            "RSS_TO_EMAIL_DRAFT",
            "RSS_TO_EMAIL_PUBLISHED",
            "SCHEDULED",
            "SCHEDULED_AB",
            "SCHEDULED_OR_PUBLISHED",
            "AUTOMATED_AB",
            "AUTOMATED_AB_VARIANT",
            "AUTOMATED_DRAFT_AB",
            "AUTOMATED_DRAFT_ABVARIANT",
            "AUTOMATED_LOSER_ABVARIANT",
        ]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and state not in allowed_values:  # noqa: E501
            raise ValueError("Invalid value for `state` ({0}), must be one of {1}".format(state, allowed_values))  # noqa: E501

        self._state = state

    @property
    def to(self):
        """Gets the to of this EmailCreateRequest.  # noqa: E501


        :return: The to of this EmailCreateRequest.  # noqa: E501
        :rtype: PublicEmailToDetails
        """
        return self._to

    @to.setter
    def to(self, to):
        """Sets the to of this EmailCreateRequest.


        :param to: The to of this EmailCreateRequest.  # noqa: E501
        :type to: PublicEmailToDetails
        """

        self._to = to

    @property
    def subcategory(self):
        """Gets the subcategory of this EmailCreateRequest.  # noqa: E501

        The email subcategory.  # noqa: E501

        :return: The subcategory of this EmailCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._subcategory

    @subcategory.setter
    def subcategory(self, subcategory):
        """Sets the subcategory of this EmailCreateRequest.

        The email subcategory.  # noqa: E501

        :param subcategory: The subcategory of this EmailCreateRequest.  # noqa: E501
        :type subcategory: str
        """
        allowed_values = [
            "ab_master",
            "ab_variant",
            "ab_loser_variant",
            "page_stub",
            "landing_page",
            "site_page",
            "legacy_page",
            "ab_master_site_page",
            "ab_variant_site_page",
            "ab_loser_variant_site_page",
            "performable_landing_page",
            "performable_landing_page_cutover",
            "staged_page",
            "automated",
            "automated_for_deal",
            "automated_for_form",
            "automated_for_form_legacy",
            "automated_for_form_buffer",
            "automated_for_form_draft",
            "rss_to_email",
            "rss_to_email_child",
            "blog_email",
            "blog_email_child",
            "optin_email",
            "optin_followup_email",
            "batch",
            "resubscribe_email",
            "unsubscribe_confirmation_email",
            "resubscribe_confirmation_email",
            "single_send_api",
            "marketing_single_send_api",
            "smtp_token",
            "localtime",
            "automated_for_ticket",
            "automated_for_leadflow",
            "automated_for_feedback_ces",
            "automated_for_feedback_nps",
            "automated_for_feedback_custom",
            "membership_registration",
            "membership_password_saved",
            "membership_password_reset",
            "membership_otp_login",
            "membership_passwordless_auth",
            "membership_email_verification",
            "membership_registration_follow_up",
            "membership_verification",
            "membership_follow_up",
            "ticket_closed_kickback_email",
            "ticket_opened_kickback_email",
            "automated_for_custom_survey",
            "discardable_stub",
            "normal_blog_post",
            "legacy_blog_post",
            "imported_blog_post",
            "automated_ab_master",
            "automated_ab_variant",
            "web_interactive",
            "portal_content",
            "page_instance_layout",
            "kb_article_instance_layout",
            "kb_listing",
            "kb_search_results",
            "kb_support_form",
            "case_study",
            "case_study_listing",
            "case_study_instance_layout",
            "UNKNOWN",
        ]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and subcategory not in allowed_values:  # noqa: E501
            raise ValueError("Invalid value for `subcategory` ({0}), must be one of {1}".format(subcategory, allowed_values))  # noqa: E501

        self._subcategory = subcategory

    @property
    def send_on_publish(self):
        """Gets the send_on_publish of this EmailCreateRequest.  # noqa: E501

        Determines whether the email will be sent immediately on publish.  # noqa: E501

        :return: The send_on_publish of this EmailCreateRequest.  # noqa: E501
        :rtype: bool
        """
        return self._send_on_publish

    @send_on_publish.setter
    def send_on_publish(self, send_on_publish):
        """Sets the send_on_publish of this EmailCreateRequest.

        Determines whether the email will be sent immediately on publish.  # noqa: E501

        :param send_on_publish: The send_on_publish of this EmailCreateRequest.  # noqa: E501
        :type send_on_publish: bool
        """

        self._send_on_publish = send_on_publish

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EmailCreateRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, EmailCreateRequest):
            return True

        return self.to_dict() != other.to_dict()
